/*
* Auftrag: Microcontroller Projekt
*---------------------------------------------------------
* Modul:   Transmit
* Version: v20
* Autor: TEAM ESCM
*---------------------------------------------------------
* Aenderungen: (neueste an oberster Stelle)
* 29.06.2014	STFU		Korrekturen
* 20.06.2014  ALLE		Doku 		
* 15.06.2014  ARMA		Source-dokumentation
*---------------------------------------------------------*/


/*
	Includes
*/
#include "stm32f4xx_conf.h"
#include "stm32f4xx.h"


/*
	Globale Variablen
*/
EXTI_InitTypeDef   EXTI_InitStructure;
GPIO_InitTypeDef   GPIO_InitStructure;
NVIC_InitTypeDef   NVIC_InitStructure;


/**
  * @brief  Stromversorgung und Takt fr SYSCFG und GPIO aktivieren					
  * @param  None
  * @retval None
  */
void RCC_initialisieren(void){

	/* Fr EXTI - GPIO */
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_SYSCFG, ENABLE); // EXTI mit Takt versorgen
  	
	/* Fr XMT */
	RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOC, ENABLE);  // GPIOC mit Takt versorgen

	/* Fr PS2 */	
	RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOE, ENABLE);  // GPIOE mit Takt versorgen
	
}


/**
  * @brief  GPIO Pins konfigurieren
	* 				Transmit:	GPIOC (Pin 0-3 Daten,Pin 15 Steuerleitung)
	*					PS2:		GPIOE (Pin 9 -> Daten | Pin 11 -> Clock)
  * @param  None
  * @retval None
  */
void GPIO_initialisieren(void){

	 /* Senddata (Daten) */
	 GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;	// Ports als Output definieren
	 GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2 | GPIO_Pin_3; // Pins 0,1,2,3 aktivieren
	 GPIO_InitStructure.GPIO_OType = GPIO_OType_PP; // Output Modus: Push-pull 
	 GPIO_InitStructure.GPIO_Speed = GPIO_Speed_2MHz;	// Abtastfrequenz auf 2MHz
	 GPIO_Init(GPIOC, &GPIO_InitStructure); // GPIOC Konfiguration bergeben  , Pointer auf Struktur mit Config
	 

	/* Steuerleitung */
	 GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT; // Port als Output definieren
	 GPIO_InitStructure.GPIO_Pin = GPIO_Pin_15; // Pin 15 aktivieren
	 GPIO_InitStructure.GPIO_OType = GPIO_OType_PP; // Output Modus: Push-pull 
	 GPIO_InitStructure.GPIO_Speed = GPIO_Speed_2MHz;	// Abtastfrequenz auf 2MHz
	 GPIO_Init(GPIOC, &GPIO_InitStructure); // GPIOC Konfiguration bergeben  , Pointer auf Struktur mit Config

	
	/* PS2 -> (Pin 9 -> Daten | Pin 11 -> Clock) */
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;  // Port als Input definieren
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_UP; // Input Modus: Pull-Up
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_9 | GPIO_Pin_11; // Pin9 und Pin11 aktivieren
  GPIO_Init(GPIOE, &GPIO_InitStructure); // GPIOE Konfiguration bergeben  , Pointer auf Struktur mit Config
	
}


/**
  * @brief  EXTI auf PE11 konfigurieren
  * @param  None
  * @retval None
  */
void EXTILine15_10_Config(void)
{
  
	 SYSCFG_EXTILineConfig(EXTI_PortSourceGPIOE, EXTI_PinSource11);	// Verbinde EXTILine15_10 mit PE11
	

  EXTI_InitStructure.EXTI_Line = EXTI_Line11;	// EXTI_Line 11
  EXTI_InitStructure.EXTI_Mode = EXTI_Mode_Interrupt; // Auf Interrupt-Mode
  EXTI_InitStructure.EXTI_Trigger = EXTI_Trigger_Falling;  // fallende Flanke (-> low) = Daten sind gueltig
	// EXTI_InitStructure.EXTI_Trigger = EXTI_Trigger_Rising;  
  EXTI_InitStructure.EXTI_LineCmd = ENABLE; // EXTI aktivieren
  EXTI_Init(&EXTI_InitStructure); // EXTI Konfiguration bergeben  , Pointer auf Struktur mit Config
	
		
  NVIC_InitStructure.NVIC_IRQChannel = EXTI15_10_IRQn; // NVIC-Kanal 15_10 fr EXTI_Line 11
  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0x01; // PreemtionPrio = 1
  NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0x01; // SubPrio = 1
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE; // NVIC-Kanal aktivieren
  NVIC_Init(&NVIC_InitStructure); // NVIC Konfiguration bergeben  , Pointer auf Struktur mit Config

}


/**
  * @brief  Main-Funktion
  * @param  None
  * @retval None
  */
int main(void){
	
	/* Stromversorgung / mit Takt versorgen  */
	RCC_initialisieren();
	
	/* Pins konfigurieren */
	GPIO_initialisieren();

	/* Interrupt fuer PS2-Clock */
 	EXTILine15_10_Config();

	/* Auf interrupt warten */
   while(1){} 

}
